@@ -22,7 +22,7 @@ class LED:
         if isinstance(value, tuple):
             self.board.set_led_hsv(self.led, *value)
         elif value in CSS4_COLOURS:
-            self.board.set_led_hsv(self.led, CSS4_COLOURS[value])
+            self.board.set_led_hsv(self.led, *CSS4_COLOURS[value])
         else:
             LOGGER.warning(f'colour for led{self.led} is neither a triple or a colour name')
 
